#
# spec file for package conky
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with    audacious
%bcond_without cmus
%ifarch %ix86 x86_64 aarch64
%bcond_without libXNVCtrl
%else
%bcond_with libXNVCtrl
%endif
Name:           conky
Version:        1.21.7
Release:        2.1
Summary:        A System Monitor
License:        GPL-3.0-or-later AND LGPL-3.0-or-later AND MIT
URL:            https://github.com/brndnmtthws/conky
Source:         https://github.com/brndnmtthws/conky/archive/v%{version}.tar.gz#/conky-%{version}.tar.gz
Source1:        conkyconf.SUSE
Source2:        conky.conf.SUSE
Source3:        README.SUSE
Patch1:         conky-1.10.1-avoid-git.patch
BuildRequires:  cmake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook2x
BuildRequires:  freetype2-devel
%if 0%{?suse_version} < 1600
BuildRequires:  gcc13
BuildRequires:  gcc13-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  gperf
BuildRequires:  hicolor-icon-theme
BuildRequires:  libiw-devel
BuildRequires:  libmicrohttpd-devel
BuildRequires:  libmysqld-devel
BuildRequires:  libtool
BuildRequires:  libxslt-tools
BuildRequires:  lua53-devel
BuildRequires:  ncurses-devel
BuildRequires:  ninja
BuildRequires:  pandoc
BuildRequires:  pkgconfig
BuildRequires:  python3-Jinja2
BuildRequires:  python3-PyYAML
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(cairo-xlib)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libical)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.52
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
Requires:       fontawesome-fonts
# This is required for imlib2 function properly.
Requires:       imlib2-loaders
Provides:       conky-cairo = %{version}
Obsoletes:      conky-cairo < %{version}
Provides:       conky-imlib2 = %{version}
Obsoletes:      conky-imlib2 < %{version}
%if %{with audacious}
BuildRequires:  pkgconfig(audacious)
BuildRequires:  pkgconfig(audclient)
BuildRequires:  pkgconfig(dbus-glib-1)
Provides:       conky-feature-audacious = %{version}
Obsoletes:      conky-feature-audacious < %{version}
%endif
%if %{with libXNVCtrl}
BuildRequires:  libXNVCtrl-devel
Provides:       conky-feature-nvidia = %{version}
Obsoletes:      conky-feature-nvidia < %{version}
%endif
%if 0%{?is_opensuse}
BuildRequires:  libircclient-devel
BuildRequires:  libtolua++-5_1-devel
%endif

%description
Conky is an configurable system monitor.

%package doc
Summary:        Documentation for conky
BuildArch:      noarch

%description doc
Conky is an configurable system monitor for X.

This package provides additional documentation about conky.

%package -n vim-plugin-conky
Summary:        Conky Configuration File Support for Vim
BuildArch:      noarch
Requires:       vim-base
Provides:       conky-vim = %{version}
Obsoletes:      conky-vim < %{version}

%description -n vim-plugin-conky
Conky is an configurable system monitor for X.

This package provides syntax highlighting support for conky
configuration files in vim.

%package -n nano-plugin-conky
Summary:        Conky Configuration File Support for nano
BuildArch:      noarch
Provides:       conky-nano = %{version}
Obsoletes:      conky-nano < %{version}

%description -n nano-plugin-conky
Conky is an configurable system monitor for X.

This package provides syntax highlighting support for conky
configuration files in nano.

%prep
%setup -q
%autopatch -p1

%build
test -x "$(type -p gcc-13)" && export CC="$_"
test -x "$(type -p g++-13)" && export CXX="$_"
%cmake -G Ninja \
	-DBUILD_APCUPSD=ON \
	-DBUILD_ARGB=ON \
%if %{with audacious}
	-DBUILD_AUDACIOUS=ON \
%else
    -DBUILD_AUDACIOUS=OFF \
%endif
	-DBUILD_BMPX=OFF \
%if %{with cmus}
	-DBUILD_CMUS=ON \
%else
    -DBUILD_CMUS=OFF \
%endif
	-DBUILD_CURL=ON \
	-DBUILD_DOCS=ON \
	-DBUILD_EVE=ON \
	-DBUILD_HDDTEMP=ON \
	-DBUILD_HTTP=ON \
	-DBUILD_I18N=ON \
	-DBUILD_IBM=ON \
	-DBUILD_ICAL=ON \
	-DBUILD_ICONV=ON \
   	-DBUILD_LUA_CAIRO=ON \
	-DBUILD_IMLIB2=ON \
    -DBUILD_LUA_IMLIB2=ON \
   	-DBUILD_LUA_RSVG=ON \
%if 0%{?is_opensuse}
    -DBUILD_IRC=ON \
%else
    -DBUILD_IRC=OFF \
%endif
	-DBUILD_XMMS2=OFF \
	-DBUILD_IOSTATS=ON \
	-DBUILD_IPV6=ON \
	-DBUILD_MATH=ON \
	-DBUILD_MOC=ON \
	-DBUILD_MPD=ON \
	-DBUILD_MYSQL=ON \
	-DBUILD_NCURSES=ON \
%if %{with libXNVCtrl}
	-DBUILD_NVIDIA=ON \
%else
    -DBUILD_NVIDIA=OFF \
%endif
	-DBUILD_PORT_MONITORS=ON \
	-DBUILD_PULSEAUDIO=ON \
	-DBUILD_RSS=ON \
	-DBUILD_OLD_CONFIG=ON \
	-DBUILD_WEATHER_METAR=ON \
	-DBUILD_WEATHER_XOAP=ON \
	-DBUILD_WLAN=ON \
	-DBUILD_X11=ON \
	-DBUILD_XDAMAGE=ON \
	-DBUILD_XDBE=ON \
	-DBUILD_XFT=ON \
	-DBUILD_XSHAPE=ON \
	-DOWN_WINDOW=ON

%ninja_build

%install
%ninja_install -C build

mkdir -p %{buildroot}%{_datadir}/vim/site/ftdetect/conkyrc.vim
install -m 644 extras/vim/ftdetect/conkyrc.vim %{buildroot}%{_datadir}/vim/site/ftdetect/conkyrc.vim
mkdir -p %dir %{buildroot}%{_datadir}/nano
install -m 644 extras/nano/conky.nanorc.j2 %{buildroot}%{_datadir}/nano/conky.nanorc.j2

# config
mkdir -p %{buildroot}%{_sysconfdir}/conky
install -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/conky/conky.conf
install -m 755 %{SOURCE1} %{buildroot}%{_bindir}/conkyconf
cp %{SOURCE3} .
sed -i "1d" extras/convert.lua
sed -i "1s/^/#!\/usr\/bin\/lua5.1\\n/" extras/convert.lua
install -m 0755 extras/convert.lua %{buildroot}%{_sysconfdir}/conky/
install -m 0644 data/conky_no_x11.conf data/conky.conf %{buildroot}%{_sysconfdir}/conky/
# clean
rm -rf %{buildroot}%{_libdir}/conky/*.{a,la}

%files
%license COPYING
%doc AUTHORS README.md README.SUSE
%dir %{_sysconfdir}/conky
%{_sysconfdir}/conky/convert.lua
%config(noreplace) %{_sysconfdir}/conky/conky.conf
%config(noreplace) %{_sysconfdir}/conky/conky_no_x11.conf
%{_bindir}/conky
%{_bindir}/conkyconf
%dir %{_libdir}/conky
%{_libdir}/conky/libcairo.so
%{_libdir}/conky/libcairo_imlib2_helper.so
%{_libdir}/conky/libcairo_xlib.so
%{_libdir}/conky/libimlib2.so
%{_libdir}/conky/librsvg.so
%{_datadir}/applications/conky.desktop
%{_datadir}/icons/hicolor/scalable/apps/conky-logomark-violet.svg
%{_datadir}/doc/conky-%{version}/
%{_libdir}/libtcp-portmon.so

%files doc
%doc %{_mandir}/man1/conky.1%{?ext_man}

%files -n vim-plugin-conky
%dir %{_datadir}/vim
%dir %{_datadir}/vim/site
%dir %{_datadir}/vim/site/ftdetect
%{_datadir}/vim/site/ftdetect/conkyrc.vim

%files -n nano-plugin-conky
%dir %{_datadir}/nano
%{_datadir}/nano/conky.nanorc.j2

%changelog
* Mon Mar  3 2025 olaf@aepfle.de
- Use gcc13 in SLE15 because because C++17 is used
* Thu Oct 17 2024 Simon Lees <sflees@suse.de>
- Update to 1.21.7
  * Too many changes in the 8 version bumps to list here
- Drop
  * conky.timestamp.patch - included upstream
  * reproducible.patch - included upstream
  * html docs
* Thu Sep 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Enable libXNVCtrl only on ix86, x86_64 and aarch64: these are the
  only architectures where NVidia drivers exist.
* Thu Oct 12 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch for deterministic output of toluapp (boo#1047218)
* Tue Mar 21 2023 olaf@aepfle.de
- Remove support for xmms2, which was dropped long ago
- Add constraints for librsvg-2.0
* Fri Mar  3 2023 olaf@aepfle.de
- Adjust package name of libXNVCtrl
- Enable conditionals libXNVCtrl and cmus, they are available in Factory
* Wed Sep 21 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.13.1:
  * Add units_spacer #1094
  * Fixes #1068 : Added custom uninstall target #1103
  * fix typo in in lua_parse description #1121
  * Fix SEGFAULT caused by out-of-bounds write #1124
  * Document unimplemented weather features #1170
  * make gw_iface work with net stat #1104
  * Include hsv_gradient.h even if BUILTIN_CONFIG is disabled #1141
  * Correct dependencies on generated header files #1207
  * GUI backends phase 1 #664
  * Http port config #1205
  * Add syntax keyword for http_port config setting #1209
  * fix #1165 by applying the padding function to nvidia objects #1166
* Wed Sep 21 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.13.0:
  * Add units_spacer #1094
  * Fixes #1068: Added custom uninstall target
  * fix typo in in lua_parse description #1121
  * Fix SEGFAULT caused by out-of-bounds write #1124
  * Document unimplemented weather features #1170
  * make gw_iface work with net stat #1104
  * Include hsv_gradient.h even if BUILTIN_CONFIG is disabled #1141
  * Correct dependencies on generated header files #1207
  * GUI backends phase 1 #664
  * Http port config #1205
  * Add syntax keyword for http_port config setting #1209
  * fix #1165 by applying the padding function to nvidia objects #1166
* Mon Apr 26 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.12.2:
  * Add support for Intel backlight
  * Fix non-IPV6 build (#1033)
  * Code cleanup
* Thu Mar  4 2021 malcolmlewis@opensuse.org
- Updated to version 1.12.1:
  * Fix an issue in the AppImage build. There are no other changes
    from v1.12.0, and so v1.12.0 and v1.12.1 are otherwise
    equivalent.
- Changes from version 1.12.0:
  * No changelog foumd(?), for full details see:
    https://github.com/brndnmtthws/conky/compare/v1.12.0...v1.12.1
- Rebase conky.timestamp.patch and drop Conky.cmake part as this is
  upstreamed.
* Tue Jul 28 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.11.6:
  * Fix negative RAM usage (#878)
  * Add nvidia driverversion variable (#889)
  * properly format PIDs longer than 5 digits
  * linux: update statistics based on newer kernel interface (#859)
  * Fix segfault on pulseaudio tunnel sinks
  * Added lower_case and upper_case commands
- Remove fix-negative-memory.patch: upstreamed
* Tue Apr 14 2020 Simon Lees <sflees@suse.com>
- Don't require nano with the nano completions, conky shouldn't
  pull in nano just for completions.
* Fri Apr  3 2020 Simon Lees <simonf.lees@suse.com>
- Fix negative ram reporting #877 #878 #909 fix-negative-memory.patch
* Tue Feb 25 2020 Simon Lees <sflees@suse.de>
- IRC support was not correctly disabled on SLE
- Re add imlib2, librsvg + cairo support on SLE (we still ship it and I'd like to
  use it in configs) it also means we don't need a second Leap package.
- Run spec-cleaner
* Mon Dec  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Remove the xmms2 dependency on openSUSE Factory.
* Tue Aug 20 2019 mvetter@suse.com
- Update to 1.11.5:
  * Fix graph leak and the uninitialized values (#858)
  * Fix `link_qual_max` getting updated with bad value
  * Fix heap use-after-free with setlocale
  * Refactorings and cleanups
  * For details see:
    https://github.com/brndnmtthws/conky/compare/v1.11.4...v1.11.5
- Remove conky-memory-leak-fix.patch: upstreamed
* Fri Jun 28 2019 Dead Mozay <dead_mozay@opensuse.org>
- Add conky-memory-leak-fix.patch Fixes a memory leak in Conky
* Mon Jun 24 2019 mvetter@suse.com
- Update to 1.11.4:
  * Added option to disable redraw on desktop change
  * Synchronize access to kstat
  * Fix various issues
  * For details see:
    https://github.com/brndnmtthws/conky/compare/v1.11.3...v1.11.4
* Tue May 28 2019 Simon Lees <sflees@suse.de>
- Clean up cmake macro's and paramaters further
- Drop unneeded conky-1.10.4-ncurses.patch
* Tue May 28 2019 Jan Engelhardt <jengelh@inai.de>
- Use %%cmake macro to resolve FIXMEs.
- Trim bias from descriptions.
* Mon May 27 2019 mvetter@suse.com
- Update to 1.11.3:
  * Allow hwmon command to accept hwmon device name
  * For details see:
    https://github.com/brndnmtthws/conky/compare/v1.11.2...v1.11.3
- Update conky.timestamp.patch and conky-1.10.1-avoid-git.patch
- Remove libical3.patch: upstreamed
- Use lua 5.3
- Install desktop file
* Mon Mar  5 2018 adam.majer@suse.de
- New upstream version 1.10.8
  + fixed segfault when HOME is unset
  + Fix segfault when kernel reports non-sequential SMP CPU indices
  + Provide support to query active port on PulseAudio's default sink
  + enable persistent view of irc messages
  + Fix SEGV in a CPU hotplug environment
  + GPLv3 is the default license
  + Support multiple include paths for libbircclient
- conky-1.10.4-ncurses.patch: comment out - doesn't seem to be needed
- conky-1.10.0-libircclient.patch: removed, upstreamed.
- conky.luamm.patch: removed, upstreamed.
- libical3.patch: adds support for libical 3.x
* Sat Mar  3 2018 jengelh@inai.de
- Explicitly request old libical
* Tue Dec 12 2017 pgajdos@suse.com
- fix build for SLE 15: buildrequire also Xdamage
- make more clear when xmms2 support is compiled in
- use pkgconfig()-style buildrequires for X libraries, package
  is build for suse_version >= 1315, so they are defined
- fix 0%%{is_opensuse} to 0%%{?is_opensuse} on one placeand remove
  is_opensuse definition, which is in my opinion useless afterwards
* Sun Dec 10 2017 i@marguerite.su
- use modular Xorg libaries if possible
- make suse is_opensuse is defined
* Wed Nov 29 2017 pgajdos@suse.com
- build with SLE 15
* Wed Nov 15 2017 pgajdos@suse.com
- change default system configuration
- add /usr/bin/conkyconf
- add README.SUSE
- require fontawesome-fonts for icons
- fate: #323638
* Thu Jul 27 2017 joerg.lorenzen@ki.tng.de
- BuildRequires libtolua++-5_1-devel on Leap.
* Tue Jun 20 2017 olaf@aepfle.de
- Fix build with conky.luamm.patch
* Tue Mar 21 2017 olaf@aepfle.de
- Remove more timestamps from binaries
* Thu Mar  2 2017 olaf@aepfle.de
- Add buildconditional for audacious, cmus, libXNVCtrl, xmms2
- Remove unused BuildRequires, convert to pkgconfig()
* Wed Jan  4 2017 olaf@aepfle.de
- Remove timestamp from binaries
- add conky.timestamp.patch
* Sat Dec 17 2016 i@marguerite.su
- update version 1.10.6
  * try more than one sysctl to get CPU temperature
  * cached versions of get_nvidia_value and get_nvidia_string_value
- changes in 1.10.5
  * check st_ctime to work with mutt MUA
  * update uri to get NOAA METAR data
* Sat Sep 24 2016 aloisio@gmx.com
- Update to version 1.10.4
- Enabled pulseaudio
- Added conky-1.10.4-ncurses.patch
* Mon May 23 2016 ronisbr@gmail.com
- Update version 1.10.2.
  * Bugfix release.
- Drop patches already applied by upstream:
  * conky-libdir.patch
  * conky-1.10.1-check_include_file.patch
* Thu Jan  7 2016 i@marguerite.su
- update version 1.10.1
  * bugfix release
  * If BUILD_IPV6=ON (default), but the user has disabled ipv6
    support in the kernel using the parameter ipv6.disable=1,
    then conky fails to open /proc/net/if_inet6. This leads to
    a segfault when conky calls fclose(file) regardless. This
    fix simply moves the fclose call into the preceding if
    statement. (boo#958897)
- drop patch: conky-1.10.0-libdir.patch
- add patch: conky-libdir.patch
- add patch: conky-1.10.1-avoid-git.patch
- add patch: conky-1.10.1-check_include_file.patch
  * fix check_include_file not found
- enable builds for sles 12
* Thu Jan  7 2016 normand@linux.vnet.ibm.com
- for suse_version after 1320
  add BuildRequires:	libtolua++-5_1-devel
* Fri Dec 18 2015 simon@simotek.net
- Add conky-1.10.0-fix-upstream-issue-187-IPV6-crash.patch fixing
  upstream issue #187 and (boo#958897) patch taken from upstream
  https://github.com/brndnmtthws/conky/commit/ee08a9e1b045e8d2f4f13a0e60c2f603b66b0d69?diff=unified
* Sat Nov 21 2015 olaf@aepfle.de
- Its always /usr/bin/lua5.1
* Thu Oct 29 2015 dimstar@opensuse.org
- Also use /usr/bin/lua5.1 on Leap 42.1 (boo#952599).
* Sat Oct  3 2015 i@marguerite.su
- fix /usr/bin/lua51, it's now /usr/bin/lua5.1 in TW.
* Sat Aug 29 2015 i@marguerite.su
- update version 1.10.0
  * Partial rewrite in C++ (from C)
  * New Lua-based config system
  * New CMake-based build system
  * Support for newer GCC versions
- drop patch: conky-1.9.0-libiw_with_libm.patch
  * upstream changed from autotools to cmake
- drop patch: fix-CVE-2011-3616.patch, upstreamed
- drop patch: fix-apcupsd.patch.
  * problematic, invalid conversion from void* to int*
- add patch: conky-1.10.0-libircclient.patch
  * fix includedir
- add patch: conky-1.10.0-libdir.patch
  * respect LIB_INSTALL_DIR
- remove old-time conditional checks:
  * lua/imlib2 are always enabled
- drop conky-cairo/imlib2 sub-packages
  * they're always enabled, no need to split
  * add Provides/Obsoletes in main package
- rename conky-vim/nano sub-packages to vim/nano-plugin-conky
- remove pseudo sub-packages:
  * there are more "features" now, we can not create more and more
    dummy packages
  * keeping packages from being switched among repositories should
    be done by users via package management system, not this way
  * add Provides/Obsoletes in main package
- drop conky-rpmlintrc
  * the error it filtered doesn't exist anymore
- drop conky.desktop
  * conky is not a desktop application. a desktop file is useless
* Tue May 26 2015 dgutu@suse.com
- Removed conky-libiw_with_libm.patch because it's not used anywhere
* Fri Jan 16 2015 aloisio@gmx.com
- Merged back changes for the packman section
* Fri Nov  9 2012 i@marguerite.su
- merged PMBS changes here. enabled more options.(OBS compatible)
- add dependency imlib2-loaders for conky-imlib2.
  or conky will keep warning can't load images.
- add two patches from debian which also confirmed by user
  please_try_again.
  * fix-apcupsd.patch, revert broken apcupsd code to previous
    working version.
  * fix-CVE-2011-3616.patch. avoid rewriting an arbitrary user file
    already upstreamed. but not in 1.9.0. remove next release.
* Sun Oct 21 2012 pascal.bleser@opensuse.org
- merged back with my changes for SLES build compatibility
* Thu Jun 21 2012 toganm@opensuse.org
- Update to 1.9.0 for changes please see
  http://conky.sourceforge.net/changelog.html
  * reworked conky-libiw_with_libm.patch as conky-1.9.0-libiw_with_libm.patch
  * removed conky-fix-curl-FTBFS.patch as fixed by upstream
* Wed Feb 29 2012 cfarrell@suse.com
- license update: GPL-3.0+
  See the COPYING file
* Mon Jan 30 2012 coolo@suse.com
- use lua51 on factory
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Thu Sep 29 2011 pascal.bleser@opensuse.org
- add cairo and imlib support where tolua++ is available,
  built as subpackages (conky-cairo and conky-imlib2)
- add patch to add -lm when linking against libiw, which is required by some
  more recent versions of libiw
* Mon Sep 26 2011 pascal.bleser@opensuse.org
- fix build issue with files in conky-doc
* Mon Sep 26 2011 nmarques@opensuse.org
- Add conky-fix-curl-FTBFS.patch: remove deprecated curl/types.h
  to fix FTBFS with newer versions of curl.
  Upstream: http://tinyurl.com/4x76bbx
* Fri Oct  8 2010 pascal.bleser@opensuse.org
- dropped conky-getaddrinfo.patch, was merged upstream
  (PATCH-FIX-OPENSUSE conky-getaddrinfo.patch fix-for-opensuse-specific-things.patch sf#3045085 pascal.bleser@opensuse.org)
- update to 1.8.1:
  * allow method to pass execgraph arguments containing spaces
  * abort curl transfers if they drop below 1000B/s for more than 60s
  * fix short_units for below kilo values
  * when we have a failure in mail thread, sleep for a bit
  * improve failure handling in mail threads
  * when we have a failure in the mail thread, lookup the hostname again in
    case the failure is due odd to DNS changes, or some other madness
  * fix segfault in ccurl_thread.c
  * fix crash in mail stuff due to bad free()
  * fix segfault in i8k (sf.net #3007167)
  * use getaddrinfo instead of gethostbyname: patches conky to use getaddrinfo
    instead of gethostbyname everywhere. gethostbyname is rather flawed and
    doesn't support IPv6 properly. Patch contributed by Pascal Bleser.
  * fix 'nvidia with ncurses segfaults' (sf.net #3006233)
  * make $fs_used_perc and $fs_bar report used space correctly; they reported
    fs->size - fs->avail, which is not correct if fs has super-user reserved
    blocks; note that now $fs_used_perc and $fs_free_perc need not add up to
    100%%, but that is consistent with what $fs_used and $fs_free do
  * fix buffer overflows in eve.c (sf.net #3034056)
  * fix bug where IMAP doesn't refresh counts after IDLE timeout
  * fix segfault in mail folder (SF: 3007493)
  * fix alignment ($align[rc]) issue for exec & lua objects
  * small build fix & zero playtime and progress bars when XMMS2 playback is stopped
  * fix tiny memleak when $top is used wrong
  * ${top}, ${top_mem} and ${top_time} are now recognized as variables; the
    parts of code doing this were in a #ifdef __linux__; the total CPU time of
    processes (${top} with "time" argument) is now printable, and ${top_time}
    works
  * fix battery_bar not parsing arguments correctly (sf: #2998034, lp: #569195)
  * bugfix: RSS interval was in secs instead of mins
  * bugfix: $alignr only worked on the first line of $execp, $execpi, $lua and $lua_parse
  * bugfix: memory and thread-deleting problems
  * bugfix: read_tcp treated a succesfull connection as failed and vice versa
  * add $nodename_short
  * bugfix: adding/removing use_xft in the config had no effect unless you
    restarted conky, reloading the config was not enough
  * fix building with Audacious >= 2.3
  * bugfix: mixerbar showed wrong values
  * bugfix: ac-adapter is sometimes called ADP1 in sysfs instead of AC
  * bugfix: battery_bar should also work without argument
  * bugfix: When the first line behind TEXT was a comment, the start of the
    second line wasn't parsed
  * fix X error when border_width is <1
  * fix device name parsing for diskio variables
  * fix bug in $if_existing
* Sun Jul  4 2010 pascal.bleser@opensuse.org
- update to 1.8.0
- split out -doc subpackage
- package vim and nano syntax highlighting configuration files into subpackages
  (instead of packaging them under the docdir)
* Wed Sep 30 2009 pascal.bleser@opensuse.org
- update to 1.7.2:
  * fixed minor memleak in pop3/imap code on config reload
  * fix crash when using $if_match with objects that may return a null pointer
    (like $rss, $weather, or $curl before data is available)
  * removed alias config option due to brokenness
  * changed xoap parsing method to xpath, in preparation to include forecast
    data
  * update MPD elapsed/progress when stopped (sf.net #2792113)
  * overhauled RSS and weather, added $curl
  * added support for X alignment across multi-lined objects (i.e., using
    $alignr with $exec)
  * www.weather.com can now be used as well as a source of weather dataµ
  * added support for $desktop, $desktop_number and $desktop_name (sf.net
    [#2040528])
  * added support for $swapfree
  * improved Lua API (lua_read_parse has been removed in favour of the
    conky_parse() Lua API call)
  * introduced new Lua Cairo and Imlib2 bindings
  * added support for $weather (experimental)
  * remove newline with comment only lines in TEXT
  * improved parsing of graph arguments, removed "log"|"normal" arguments in
    favour of -l switch
  * fix escaping of comments in TEXT (sf.net #2813390)
  * fix segfault in to_real_path, it's sometimes called with the same source
    and dest without checking the length, causing a segfault
  * use the internal process list for if_running on Linux
* Sat Jun 13 2009 pascal.bleser@opensuse.org
- update to 1.7.1.1:
  * fixed a regression which causes fonts to not be rendered properly with
    certain types of windows
  * fix bug in comments within TEXT (where the line contains just '#') (sf.net
    [#2803586])
  * fix bug in $mails (sf.net #2802529)
* Tue Jun  9 2009 pascal.bleser@opensuse.org
- update to 1.7.1
* Sun May  3 2009 pascal.bleser@opensuse.org
- update to 1.7.0
* Tue Oct  7 2008 bwalle@suse.de
- fix build on Factory
* Wed Sep 17 2008 guru@unixtech.be
- update to 1.6.1
* Tue Jul 22 2008 guru@unixtech.be
- new upstream version
* Sun Mar 23 2008 guru@unixtech.be
- new upstream version
* Thu Dec  6 2007 guru@unixtech.be
- new upstream version
* Wed Oct  3 2007 guru@unixtech.be
- update to 1.4.7
- moved to openSUSE Build Service
* Wed Jan  3 2007 guru@unixtech.be
- new upstream version
* Sat Sep  2 2006 guru@unixtech.be
- new upstream version
* Wed Feb 15 2006 guru@unixtech.be
- new upstream version
* Mon Jan  2 2006 guru@unixtech.be
- removed cairo flags, as removed from conky codebase
- new upstream version
- rewrote spec file
* Tue Nov  1 2005 guru@unixtech.be
- new package
